jabbar
======

Just Another Beautiful progress BAR.

jabbar is a python package implementing a simple progress bar.


Install
-------

jabbar can be installed from `PyPI <https://pypi.python.org>`_ via

.. code-block:: sh

    $ pip install jabbar

or from the latest code on `GitHub <https://github.com/yannikschaelte/jabbar>`_ with

.. code-block:: sh

    $ pip install git+https://github.com/yannikschaelte/jabbar.git


Get started
-----------

TODO

License
-------

jabbar is available under a MIT license.
